@@ -1,4 +1,9 @@
-"""Submodule for NeuroKit."""
+"""
+Submodule for NeuroKit.
+"""
 
-from .bio_process import bio_process
 from .bio_analyze import bio_analyze
+from .bio_process import bio_process
+
+
+__all__ = ["bio_process", "bio_analyze"]
