@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 import numpy as np
-
-
+import pandas as pd
 
 
 def entropy_shannon(signal):
-    """Compute the Shannon entropy (SE)
+    """
+    Shannon entropy (SE)
 
-    Entropy is a measure of unpredictability of the state, or equivalently, of its average information content. Shannon entropy (SE) is one of the first and most basic measure of entropy and a foundational concept of information theory. Shannon’s entropy quantifies the amount of information in a variable.
+    Python implementation of Shannon entropy (SE). Entropy is a measure of unpredictability of the state, or equivalently, of its average information content. Shannon entropy (SE) is one of the first and most basic measure of entropy and a foundational concept of information theory. Shannon’s entropy quantifies the amount of information in a variable.
 
+    This function can be called either via ``entropy_shannon()`` or ``complexity_se()``.
 
     Parameters
     ----------
     signal : list, array or Series
-        The signal channel in the form of a vector of values.
+        The signal (i.e., a time series) in the form of a vector of values.
 
 
     Returns
@@ -31,8 +31,8 @@ def entropy_shannon(signal):
     >>> import neurokit2 as nk
     >>>
     >>> signal = nk.signal_simulate(duration=2, frequency=5)
-    >>> nk.entropy_shannon(signal)
-    10.965784284661922
+    >>> entropy = nk.entropy_shannon(signal)
+    >>> entropy #doctest: +SKIP
 
 
     References
@@ -40,6 +40,7 @@ def entropy_shannon(signal):
     - `pyEntropy` <https://github.com/nikdon/pyEntropy>`_
     - `EntroPy` <https://github.com/raphaelvallat/entropy>`_
     - `nolds` <https://github.com/CSchoel/nolds>`_
+
     """
     # Check if string
     if not isinstance(signal, str):
@@ -51,7 +52,7 @@ def entropy_shannon(signal):
     data_set = list(set(signal))
     freq_list = []
     for entry in data_set:
-        counter = 0.
+        counter = 0.0
         for i in signal:
             if i == entry:
                 counter += 1
