@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 import os
 
+import pandas as pd
+
 
 def data(dataset="bio_eventrelated_100hz"):
-    """Example datasets
+    """
+    Example datasets.
 
     Download and load available `example datasets <https://github.com/neuropsychology/NeuroKit/tree/master/data#datasets>`_. Note that an internet connexion is necessary.
 
@@ -24,6 +26,7 @@ def data(dataset="bio_eventrelated_100hz"):
     >>> import neurokit2 as nk
     >>>
     >>> data = nk.data("bio_eventrelated_100hz")
+
     """
     # TODO: one could further improve this function with like
     # selectors 'ecg=True, eda=True, restingstate=True' that would
@@ -31,8 +34,14 @@ def data(dataset="bio_eventrelated_100hz"):
 
     path = "https://raw.githubusercontent.com/neuropsychology/NeuroKit/master/data/"
 
+    # Specific case
+    if dataset.lower() in ["eeg", "eeg.txt"]:
+        data = pd.read_csv(path + "eeg.txt")
+        return data.values[:, 0]
+
+    # General case
     file, ext = os.path.splitext(dataset)
-    if ext == '':
+    if ext == "":
         data = pd.read_csv(path + dataset + ".csv")
     else:
         data = pd.read_csv(path + dataset)
