@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 import os
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
 from ..signal import signal_resample
 
 
-
 def read_acqknowledge(filename, sampling_rate="max", resample_method="interpolation", impute_missing=True):
-    """Read and format a BIOPAC's AcqKnowledge file into a pandas' dataframe.
+    """
+    Read and format a BIOPAC's AcqKnowledge file into a pandas' dataframe.
 
     The function outputs both the dataframe and the sampling rate (encoded within the AcqKnowledge) file.
 
@@ -37,25 +37,24 @@ def read_acqknowledge(filename, sampling_rate="max", resample_method="interpolat
     ----------
     >>> import neurokit2 as nk
     >>>
-    >>> data, sampling_rate = nk.read_acqknowledge('file.acq')
+    >>> data, sampling_rate = nk.read_acqknowledge('file.acq') #doctest: +SKIP
+
     """
     # Try loading bioread
     try:
         import bioread
     except ImportError:
-        raise ImportError("NeuroKit error: read_acqknowledge(): the 'bioread' "
-                          "module is required for this function to run. ",
-                          "Please install it first (`pip install bioread`).")
-
+        raise ImportError(
+            "NeuroKit error: read_acqknowledge(): the 'bioread' module is required for this function to run. ",
+            "Please install it first (`pip install bioread`).",
+        )
 
     # Check filename
     if ".acq" not in filename:
         filename += ".acq"
 
     if os.path.exists(filename) is False:
-        raise ValueError("NeuroKit error: read_acqknowledge(): couldn't find"
-                         " the following file: " + filename)
-
+        raise ValueError("NeuroKit error: read_acqknowledge(): couldn't find the following file: " + filename)
 
     # Read file
     file = bioread.read(filename)
@@ -73,16 +72,17 @@ def read_acqknowledge(filename, sampling_rate="max", resample_method="interpolat
         signal = np.array(file.named_channels[channel].data)
 
         # Fill signal interruptions
-        if impute_missing is True:
-            if np.isnan(np.sum(signal)):
-                signal = pd.Series(signal).fillna(method="pad").values
+        if impute_missing is True and np.isnan(np.sum(signal)):
+            signal = pd.Series(signal).fillna(method="pad").values
 
         # Resample if necessary
         if file.named_channels[channel].samples_per_second != sampling_rate:
-            signal = signal_resample(signal,
-                                     sampling_rate=file.named_channels[channel].samples_per_second,
-                                     desired_sampling_rate=sampling_rate,
-                                     method=resample_method)
+            signal = signal_resample(
+                signal,
+                sampling_rate=file.named_channels[channel].samples_per_second,
+                desired_sampling_rate=sampling_rate,
+                method=resample_method,
+            )
         data[channel] = signal
 
     # Sanitize lengths
@@ -95,8 +95,9 @@ def read_acqknowledge(filename, sampling_rate="max", resample_method="interpolat
             if len(data[channel]) > length:
                 data[channel] = data[channel][0:length]
             if len(data[channel]) < length:
-                data[channel] = np.concatenate([data[channel],
-                                               np.full((length-len(data[channel])), data[channel][-1])])
+                data[channel] = np.concatenate(
+                    [data[channel], np.full((length - len(data[channel])), data[channel][-1])]
+                )
 
     # Final dataframe
     df = pd.DataFrame(data)
