@@ -1,13 +1,12 @@
 # - * - coding: utf-8 - * -
 
+from ..signal import signal_fixpeaks, signal_formatpeaks
 from .ecg_findpeaks import ecg_findpeaks
-from .ecg_fixpeaks import ecg_fixpeaks
-from ..signal import signal_formatpeaks
 
 
-def ecg_peaks(ecg_cleaned, sampling_rate=1000, method="neurokit",
-              correct_artifacts=False):
-    """Find R-peaks in an ECG signal.
+def ecg_peaks(ecg_cleaned, sampling_rate=1000, method="neurokit", correct_artifacts=False):
+    """
+    Find R-peaks in an ECG signal.
 
     Find R-peaks in an ECG signal using the specified method.
 
@@ -41,7 +40,8 @@ def ecg_peaks(ecg_cleaned, sampling_rate=1000, method="neurokit",
 
     See Also
     --------
-    ecg_clean, ecg_findpeaks, ecg_fixpeaks, ecg_rate, ecg_process, ecg_plot
+    ecg_clean, ecg_findpeaks, ecg_process, ecg_plot, signal_rate,
+    signal_fixpeaks
 
     Examples
     --------
@@ -50,7 +50,8 @@ def ecg_peaks(ecg_cleaned, sampling_rate=1000, method="neurokit",
     >>> ecg = nk.ecg_simulate(duration=10, sampling_rate=1000)
     >>> cleaned = nk.ecg_clean(ecg, sampling_rate=1000)
     >>> signals, info = nk.ecg_peaks(cleaned, correct_artifacts=True)
-    >>> nk.events_plot(info["ECG_R_Peaks"], cleaned)
+    >>> nk.events_plot(info["ECG_R_Peaks"], cleaned) #doctest: +ELLIPSIS
+    <Figure ...>
 
     References
     ----------
@@ -60,18 +61,16 @@ def ecg_peaks(ecg_cleaned, sampling_rate=1000, method="neurokit",
     - Jiapu Pan and Willis J. Tompkins. A Real-Time QRS Detection Algorithm. In: IEEE Transactions on Biomedical Engineering BME-32.3 (1985), pp. 230–236.
     - C. Zeelenberg, A single scan algorithm for QRS detection and feature extraction, IEEE Comp. in Cardiology, vol. 6, pp. 37-42, 1979
     - A. Lourenco, H. Silva, P. Leite, R. Lourenco and A. Fred, "Real Time Electrocardiogram Segmentation for Finger Based ECG Biometrics", BIOSIGNALS 2012, pp. 49-54, 2012.
+
     """
-    rpeaks = ecg_findpeaks(ecg_cleaned, sampling_rate=sampling_rate,
-                           method=method)
+    rpeaks = ecg_findpeaks(ecg_cleaned, sampling_rate=sampling_rate, method=method)
 
     if correct_artifacts:
-        _, rpeaks = ecg_fixpeaks(rpeaks,
-                                 sampling_rate=sampling_rate,
-                                 iterative=True)
+        _, rpeaks = signal_fixpeaks(rpeaks, sampling_rate=sampling_rate, iterative=True, method="Kubios")
 
-    instant_peaks = signal_formatpeaks(rpeaks,
-                                       desired_length=len(ecg_cleaned),
-                                       peak_indices=rpeaks["ECG_R_Peaks"])
+        rpeaks = {"ECG_R_Peaks": rpeaks}
+
+    instant_peaks = signal_formatpeaks(rpeaks, desired_length=len(ecg_cleaned), peak_indices=rpeaks)
     signals = instant_peaks
     info = rpeaks
 
