@@ -3,13 +3,13 @@ import numpy as np
 import pandas as pd
 
 from ..signal import signal_phase
-from .ecg_peaks import ecg_peaks
 from .ecg_delineate import ecg_delineate
+from .ecg_peaks import ecg_peaks
 
 
-
-def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sampling_rate=None):
-    """Compute cardiac phase (for both atrial and ventricular).
+def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method="peak", sampling_rate=None):
+    """
+    Compute cardiac phase (for both atrial and ventricular).
 
     Finds the cardiac phase, labelled as 1 for systole and 0 for diastole.
     Parameters
@@ -28,14 +28,14 @@ def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sam
         A DataFrame of same length as `ecg_signal` containing the following
         columns:
 
-        - *"ECG_Phase_Artrial"*: cardiac phase, marked by "1" for systole
+        - *"ECG_Phase_Atrial"*: cardiac phase, marked by "1" for systole
           and "0" for diastole.
-        - *"ECG_Ventricular_Phase"*: cardiac phase, marked by "1" for systole
-          and "0" for diastole.
-          *"ECG_Atrial_PhaseCompletion"*: cardiac phase (atrial) completion,
+        - *"ECG_Phase_Completion_Atrial"*: cardiac phase (atrial) completion,
           expressed in percentage (from 0 to 1), representing the stage of the
           current cardiac phase.
-          *"ECG_Ventricular_PhaseCompletion"*: cardiac phase (ventricular)
+        - *"ECG_Phase_Ventricular"*: cardiac phase, marked by "1" for systole
+          and "0" for diastole.
+        - *"ECG_Phase_Completion_Ventricular"*: cardiac phase (ventricular)
           completion, expressed in percentage (from 0 to 1), representing the
           stage of the current cardiac phase.
 
@@ -52,20 +52,19 @@ def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sam
     >>> _, rpeaks = nk.ecg_peaks(cleaned)
     >>> signals, waves = nk.ecg_delineate(cleaned, rpeaks, sampling_rate=1000)
     >>>
-    >>> cardiac_phase = nk.ecg_phase(ecg_cleaned=cleaned,
-    >>>                              rpeaks=rpeaks,
-    >>>                              delineate_info=waves,
-    >>>                              sampling_rate=1000)
-    >>> nk.signal_plot([cleaned, cardiac_phase], standardize=True)
+    >>> cardiac_phase = nk.ecg_phase(ecg_cleaned=cleaned, rpeaks=rpeaks,
+    ...                              delineate_info=waves, sampling_rate=1000)
+    >>> nk.signal_plot([cleaned, cardiac_phase], standardize=True) #doctest: +ELLIPSIS
+
     """
     # Sanitize inputs
     if rpeaks is None:
         if sampling_rate is not None:
             _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate)
         else:
-            raise ValueError("rpeaks will be obtained using `nk.ecg_peaks`. "
-                             "Please provide the sampling_rate of "
-                             "ecg_signal.")
+            raise ValueError(
+                "R-peaks will be obtained using `nk.ecg_peaks`. Please provide the sampling_rate of ecg_signal."
+            )
     # Try retrieving right column
     if isinstance(rpeaks, dict):
         rpeaks = rpeaks["ECG_R_Peaks"]
@@ -75,17 +74,14 @@ def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sam
 
     # Try retrieving right column
     if isinstance(delineate_info, dict):
-        toffsets = delineate_info['ECG_T_Offsets']
+        toffsets = delineate_info["ECG_T_Offsets"]
         toffsets = [int(x) for x in toffsets if ~np.isnan(x)]
         toffsets = np.array(toffsets)
 
-        ppeaks = delineate_info['ECG_P_Peaks']
+        ppeaks = delineate_info["ECG_P_Peaks"]
         ppeaks = [int(x) for x in ppeaks if ~np.isnan(x)]
         ppeaks = np.array(ppeaks)
 
-
-
-
     # Atrial Phase
     atrial = np.full(len(ecg_cleaned), np.nan)
     atrial[rpeaks] = 0.0
@@ -97,9 +93,6 @@ def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sam
     # Atrial Phase Completion
     atrial_completion = signal_phase(atrial, method="percent")
 
-
-
-
     # Ventricular Phase
     ventricular = np.full(len(ecg_cleaned), np.nan)
     ventricular[toffsets] = 0.0
@@ -111,11 +104,11 @@ def ecg_phase(ecg_cleaned, rpeaks=None, delineate_info=None, method='peak',  sam
     # Ventricular Phase Completion
     ventricular_comletion = signal_phase(ventricular, method="percent")
 
-
-
-    out = pd.DataFrame({"ECG_Atrial_Phase": atrial,
-                        "ECG_Ventricular_Phase": ventricular,
-                        "ECG_Atrial_PhaseCompletion": atrial_completion,
-                        "ECG_Ventricular_PhaseCompletion": ventricular_comletion})
-
-    return out
+    return pd.DataFrame(
+        {
+            "ECG_Phase_Atrial": atrial,
+            "ECG_Phase_Completion_Atrial": atrial_completion,
+            "ECG_Phase_Ventricular": ventricular,
+            "ECG_Phase_Completion_Ventricular": ventricular_comletion,
+        }
+    )
