@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
-import numpy as np
-import scipy
 import math
 
-from ..signal import signal_resample
-from ..signal import signal_distort
+import numpy as np
+import scipy
+
+from ..signal import signal_distort, signal_resample
 
 
-def ecg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
-                 heart_rate=70, method="ecgsyn", random_state=None):
-    """Simulate an ECG/EKG signal
+def ecg_simulate(
+    duration=10, length=None, sampling_rate=1000, noise=0.01, heart_rate=70, method="ecgsyn", random_state=None
+):
+    """
+    Simulate an ECG/EKG signal.
 
     Generate an artificial (synthetic) ECG signal of a given duration and sampling rate using either the ECGSYN dynamical model (McSharry et al., 2003) or a simpler model based on Daubechies wavelets to roughly approximate cardiac cycles.
 
@@ -48,7 +49,10 @@ def ecg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
     >>> ecg1 = nk.ecg_simulate(duration=10, method="simple")
     >>> ecg2 = nk.ecg_simulate(duration=10, method="ecgsyn")
     >>> pd.DataFrame({"ECG_Simple": ecg1,
-                      "ECG_Complex": ecg2}).plot(subplots=True)
+    ...               "ECG_Complex": ecg2}).plot(subplots=True) #doctest: +ELLIPSIS
+    array([<matplotlib.axes._subplots.AxesSubplot object at ...>,
+       <matplotlib.axes._subplots.AxesSubplot object at ...>],
+      dtype=object)
 
     See Also
     --------
@@ -59,6 +63,7 @@ def ecg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
     -----------
     - McSharry, P. E., Clifford, G. D., Tarassenko, L., & Smith, L. A. (2003). A dynamical model for generating synthetic electrocardiogram signals. IEEE transactions on biomedical engineering, 50(3), 289-294.
     - https://github.com/diarmaidocualain/ecg_simulation
+
     """
     # Seed the random generator for reproducible results
     np.random.seed(random_state)
@@ -71,55 +76,53 @@ def ecg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
 
     # Run appropriate method
     if method.lower() in ["simple", "daubechies"]:
-        ecg = _ecg_simulate_daubechies(duration=duration,
-                                       length=length,
-                                       sampling_rate=sampling_rate,
-                                       heart_rate=heart_rate)
+        ecg = _ecg_simulate_daubechies(
+            duration=duration, length=length, sampling_rate=sampling_rate, heart_rate=heart_rate
+        )
     else:
         approx_number_beats = int(np.round(duration * (heart_rate / 60)))
-        ecg = _ecg_simulate_ecgsyn(sfecg=sampling_rate,
-                                   N=approx_number_beats,
-                                   Anoise=0,
-                                   hrmean=heart_rate,
-                                   hrstd=1,
-                                   lfhfratio=0.5,
-                                   sfint=sampling_rate,
-                                   ti=(-70, -15, 0, 15, 100),
-                                   ai=(1.2, -5, 30, -7.5, 0.75),
-                                   bi=(0.25, 0.1, 0.1, 0.1, 0.4))
+        ecg = _ecg_simulate_ecgsyn(
+            sfecg=sampling_rate,
+            N=approx_number_beats,
+            Anoise=0,
+            hrmean=heart_rate,
+            hrstd=1,
+            lfhfratio=0.5,
+            sfint=sampling_rate,
+            ti=(-70, -15, 0, 15, 100),
+            ai=(1.2, -5, 30, -7.5, 0.75),
+            bi=(0.25, 0.1, 0.1, 0.1, 0.4),
+        )
         # Cut to match expected length
         ecg = ecg[0:length]
 
     # Add random noise
     if noise > 0:
-        ecg = signal_distort(ecg,
-                             sampling_rate=sampling_rate,
-                             noise_amplitude=noise,
-                             noise_frequency=[5, 10, 100],
-                             noise_shape="laplace",
-                             random_state=random_state,
-                             silent=True)
+        ecg = signal_distort(
+            ecg,
+            sampling_rate=sampling_rate,
+            noise_amplitude=noise,
+            noise_frequency=[5, 10, 100],
+            noise_shape="laplace",
+            random_state=random_state,
+            silent=True,
+        )
 
     # Reset random seed (so it doesn't affect global)
     np.random.seed(None)
-    return(ecg)
-
-
-
-
-
-
-
+    return ecg
 
 
 # =============================================================================
 # Daubechies
 # =============================================================================
-def _ecg_simulate_daubechies(duration=10, length=None, sampling_rate=1000,
-                             heart_rate=70):
-    """Generate an artificial (synthetic) ECG signal of a given duration and sampling rate.
+def _ecg_simulate_daubechies(duration=10, length=None, sampling_rate=1000, heart_rate=70):
+    """
+    Generate an artificial (synthetic) ECG signal of a given duration and sampling rate.
+
     It uses a 'Daubechies' wavelet that roughly approximates a single cardiac cycle.
     This function is based on `this script <https://github.com/diarmaidocualain/ecg_simulation>`_.
+
     """
     # The "Daubechies" wavelet is a rough approximation to a real, single, cardiac cycle
     cardiac = scipy.signal.wavelets.daub(10)
@@ -136,24 +139,33 @@ def _ecg_simulate_daubechies(duration=10, length=None, sampling_rate=1000,
     # Change amplitude
     ecg = ecg * 10
 
-
     # Resample
-    ecg = signal_resample(ecg,
-                          sampling_rate=int(len(ecg)/10),
-                          desired_length=length,
-                          desired_sampling_rate=sampling_rate)
-
-    return(ecg)
+    ecg = signal_resample(
+        ecg, sampling_rate=int(len(ecg) / 10), desired_length=length, desired_sampling_rate=sampling_rate
+    )
 
+    return ecg
 
 
 # =============================================================================
 # ECGSYN
 # =============================================================================
-def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfratio=0.5, sfint=512,
-                         ti=(-70, -15, 0, 15, 100), ai=(1.2, -5, 30, -7.5, 0.75), bi=(0.25, 0.1, 0.1, 0.1, 0.4)):
+def _ecg_simulate_ecgsyn(
+    sfecg=256,
+    N=256,
+    Anoise=0,
+    hrmean=60,
+    hrstd=1,
+    lfhfratio=0.5,
+    sfint=512,
+    ti=(-70, -15, 0, 15, 100),
+    ai=(1.2, -5, 30, -7.5, 0.75),
+    bi=(0.25, 0.1, 0.1, 0.1, 0.4),
+):
     """
-    This function is a python translation of the matlab script by `McSharry & Clifford (2013) <https://physionet.org/content/ecgsyn>`_.
+    This function is a python translation of the matlab script by `McSharry & Clifford (2013)
+
+    <https://physionet.org/content/ecgsyn>`_.
 
     Parameters
     ----------
@@ -170,17 +182,19 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
     % ai = z-position of extrema
     % bi = Gaussian width of peaks
 
-    Examples
-    --------
-    >>> import matplotlib.pyplot as plt
-    >>>
-    >>> s = _ecg_simulate_ecgsynth()
-    >>> x = np.linspace(0, len(s)-1, len(s))
-    >>> num_points = 4000
-    >>>
-    >>> num_points = min(num_points, len(s))
-    >>> plt.plot(x[:num_points], s[:num_points])
-    >>> plt.show()
+#    Examples
+#    --------
+#    >>> import matplotlib.pyplot as plt
+#    >>> import neurokit2 as nk
+#    >>>
+#    >>> s = _ecg_simulate_ecgsynth()
+#    >>> x = np.linspace(0, len(s)-1, len(s))
+#    >>> num_points = 4000
+#    >>>
+#    >>> num_points = min(num_points, len(s))
+#    >>> plt.plot(x[:num_points], s[:num_points]) #doctest: +SKIP
+#    >>> plt.show() #doctest: +SKIP
+
     """
 
     if not isinstance(ti, np.ndarray):
@@ -190,19 +204,25 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
     if not isinstance(bi, np.ndarray):
         bi = np.array(bi)
 
-    ti = ti*np.pi/180
+    ti = ti * np.pi / 180
 
     # Adjust extrema parameters for mean heart rate
-    hrfact = np.sqrt(hrmean/60)
+    hrfact = np.sqrt(hrmean / 60)
     hrfact2 = np.sqrt(hrfact)
     bi = hrfact * bi
-    ti = np.array([hrfact2, hrfact, 1, hrfact, hrfact2])*ti
+    ti = np.array([hrfact2, hrfact, 1, hrfact, hrfact2]) * ti
 
     # Check that sfint is an integer multiple of sfecg
-    q = np.round(sfint/sfecg)
-    qd = sfint/sfecg
+    q = np.round(sfint / sfecg)
+    qd = sfint / sfecg
     if q != qd:
-        raise ValueError('Internal sampling frequency (sfint) must be an integer multiple of the ECG sampling frequency (sfecg). Your current choices are: sfecg = ' + str(sfecg) + ' and sfint = ' + str(sfint) + '.')
+        raise ValueError(
+            "Internal sampling frequency (sfint) must be an integer multiple of the ECG sampling frequency (sfecg). Your current choices are: sfecg = "
+            + str(sfecg)
+            + " and sfint = "
+            + str(sfint)
+            + "."
+        )
 
     # Define frequency parameters for rr process
     # flo and fhi correspond to the Mayer waves and respiratory rate respectively
@@ -214,10 +234,10 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
 
     # Calculate time scales for rr and total output
     sfrr = 1
-    trr = 1/sfrr
-    tstep = 1/sfecg
-    rrmean = 60/hrmean
-    n = 2**(np.ceil(np.log2(N*rrmean/trr)))
+    trr = 1 / sfrr
+    tstep = 1 / sfecg
+    rrmean = 60 / hrmean
+    n = 2 ** (np.ceil(np.log2(N * rrmean / trr)))
 
     rr0 = _ecg_simulate_rrprocess(flo, fhi, flostd, fhistd, lfhfratio, hrmean, hrstd, sfrr, n)
 
@@ -225,13 +245,13 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
     rr = signal_resample(rr0, sampling_rate=1, desired_sampling_rate=sfint)
 
     # Make the rrn time series
-    dt = 1/sfint
+    dt = 1 / sfint
     rrn = np.zeros(len(rr))
     tecg = 0
     i = 0
     while i < len(rr):
-        tecg = tecg+rr[i]
-        ip = int(np.round(tecg/dt))
+        tecg += rr[i]
+        ip = int(np.round(tecg / dt))
         rrn[i:ip] = rr[i]
         i = ip
     Nt = ip
@@ -242,16 +262,14 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
     # tspan is a tuple of (min, max) which defines the lower and upper bound of t in ODE
     # t_eval is the list of desired t points for ODE
     # in Matlab, ode45 can accepts both tspan and t_eval in one argument
-    Tspan = [0, (Nt-1)*dt]
-    t_eval = np.linspace(0, (Nt-1)*dt, Nt)
+    Tspan = [0, (Nt - 1) * dt]
+    t_eval = np.linspace(0, (Nt - 1) * dt, Nt)
 
     # as passing extra arguments to derivative function is not supported yet in solve_ivp
     # lambda function is used to serve the purpose
-    result = scipy.integrate.solve_ivp(lambda t, x: _ecg_simulate_derivsecgsyn(t, x, rrn, ti, sfint, ai, bi),
-                                       Tspan,
-                                       x0,
-                                       t_eval=t_eval
-                                       )
+    result = scipy.integrate.solve_ivp(
+        lambda t, x: _ecg_simulate_derivsecgsyn(t, x, rrn, ti, sfint, ai, bi), Tspan, x0, t_eval=t_eval
+    )
     T = result.t
     X0 = result.y
 
@@ -263,13 +281,11 @@ def _ecg_simulate_ecgsyn(sfecg=256, N=256, Anoise=0, hrmean=60, hrstd=1, lfhfrat
     zmin = np.min(z)
     zmax = np.max(z)
     zrange = zmax - zmin
-    z = (z - zmin)*1.6/zrange - 0.4
+    z = (z - zmin) * 1.6 / zrange - 0.4
 
     # include additive uniformly distributed measurement noise
-    eta = 2*np.random.uniform(len(z))-1
-    s = z + Anoise*eta
-
-    return s
+    eta = 2 * np.random.uniform(len(z)) - 1
+    return z + Anoise * eta  # Return signal
 
 
 def _ecg_simulate_derivsecgsyn(t, x, rr, ti, sfint, ai, bi):
@@ -281,11 +297,11 @@ def _ecg_simulate_derivsecgsyn(t, x, rr, ti, sfint, ai, bi):
     a0 = 1.0 - np.sqrt(x[0] ** 2 + x[1] ** 2) / r0
 
     ip = np.floor(t * sfint).astype(int)
-    w0 = 2*np.pi/rr[min(ip, len(rr)-1)]
+    w0 = 2 * np.pi / rr[min(ip, len(rr) - 1)]
     # w0 = 2*np.pi/rr[ip[ip <= np.max(rr)]]
 
     fresp = 0.25
-    zbase = 0.005 * np.sin(2*np.pi*fresp*t)
+    zbase = 0.005 * np.sin(2 * np.pi * fresp * t)
 
     dx1dt = a0 * x[0] - w0 * x[1]
     dx2dt = a0 * x[1] + w0 * x[0]
@@ -299,33 +315,34 @@ def _ecg_simulate_derivsecgsyn(t, x, rr, ti, sfint, ai, bi):
     return dxdt
 
 
-def _ecg_simulate_rrprocess(flo=0.1, fhi=0.25, flostd=0.01, fhistd=0.01, lfhfratio=0.5, hrmean=60, hrstd=1, sfrr=1, n=256):
-    w1 = 2*np.pi*flo
-    w2 = 2*np.pi*fhi
-    c1 = 2*np.pi*flostd
-    c2 = 2*np.pi*fhistd
+def _ecg_simulate_rrprocess(
+    flo=0.1, fhi=0.25, flostd=0.01, fhistd=0.01, lfhfratio=0.5, hrmean=60, hrstd=1, sfrr=1, n=256
+):
+    w1 = 2 * np.pi * flo
+    w2 = 2 * np.pi * fhi
+    c1 = 2 * np.pi * flostd
+    c2 = 2 * np.pi * fhistd
     sig2 = 1
     sig1 = lfhfratio
-    rrmean = 60/hrmean
-    rrstd = 60*hrstd/(hrmean*hrmean)
+    rrmean = 60 / hrmean
+    rrstd = 60 * hrstd / (hrmean * hrmean)
 
-    df = sfrr/n
-    w = np.arange(n)*2*np.pi*df
-    dw1 = w-w1
-    dw2 = w-w2
+    df = sfrr / n
+    w = np.arange(n) * 2 * np.pi * df
+    dw1 = w - w1
+    dw2 = w - w2
 
-    Hw1 = sig1*np.exp(-0.5*(dw1/c1)**2)/np.sqrt(2*np.pi*c1**2)
-    Hw2 = sig2*np.exp(-0.5*(dw2/c2)**2)/np.sqrt(2*np.pi*c2**2)
+    Hw1 = sig1 * np.exp(-0.5 * (dw1 / c1) ** 2) / np.sqrt(2 * np.pi * c1 ** 2)
+    Hw2 = sig2 * np.exp(-0.5 * (dw2 / c2) ** 2) / np.sqrt(2 * np.pi * c2 ** 2)
     Hw = Hw1 + Hw2
-    Hw0 = np.concatenate((Hw[0:int(n/2)], Hw[int(n/2)-1::-1]))
-    Sw = (sfrr/2)*np.sqrt(Hw0)
+    Hw0 = np.concatenate((Hw[0 : int(n / 2)], Hw[int(n / 2) - 1 :: -1]))
+    Sw = (sfrr / 2) * np.sqrt(Hw0)
 
-    ph0 = 2*np.pi*np.random.uniform(size=int(n/2-1))
+    ph0 = 2 * np.pi * np.random.uniform(size=int(n / 2 - 1))
     ph = np.concatenate([[0], ph0, [0], -np.flipud(ph0)])
-    SwC = Sw * np.exp(1j*ph)
-    x = (1/n)*np.real(np.fft.ifft(SwC))
+    SwC = Sw * np.exp(1j * ph)
+    x = (1 / n) * np.real(np.fft.ifft(SwC))
 
     xstd = np.std(x)
-    ratio = rrstd/xstd
-    rr = rrmean + x*ratio
-    return rr
+    ratio = rrstd / xstd
+    return rrmean + x * ratio  # Return RR
