@@ -1,4 +1,9 @@
-"""Submodule for NeuroKit."""
+"""
+Submodule for NeuroKit.
+"""
 
 from .mne_channel_add import mne_channel_add
 from .mne_channel_extract import mne_channel_extract
+
+
+__all__ = ["mne_channel_add", "mne_channel_extract"]
