@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 import pandas as pd
 
-from .emg_clean import emg_clean
-from .emg_amplitude import emg_amplitude
 from .emg_activation import emg_activation
+from .emg_amplitude import emg_amplitude
+from .emg_clean import emg_clean
 
 
 def emg_process(emg_signal, sampling_rate=1000):
-    """Process a electromyography (EMG) signal.
+    """
+    Process a electromyography (EMG) signal.
 
     Convenience function that automatically processes
     an electromyography signal.
@@ -47,9 +48,11 @@ def emg_process(emg_signal, sampling_rate=1000):
     --------
     >>> import neurokit2 as nk
     >>>
-    >>> emg = nk.emg_simulate(duration=10, sampling_rate=1000, n_bursts=3)
+    >>> emg = nk.emg_simulate(duration=10, sampling_rate=1000, burst_number=3)
     >>> signals, info = nk.emg_process(emg, sampling_rate=1000)
-    >>> nk.emg_plot(signals)
+    >>> fig = nk.emg_plot(signals)
+    >>> fig #doctest: +SKIP
+
     """
     # Clean signal
     emg_cleaned = emg_clean(emg_signal, sampling_rate=sampling_rate)
@@ -58,14 +61,10 @@ def emg_process(emg_signal, sampling_rate=1000):
     amplitude = emg_amplitude(emg_cleaned)
 
     # Get onsets, offsets, and periods of activity
-    activity_signal, info = emg_activation(amplitude,
-                                           sampling_rate=sampling_rate,
-                                           threshold='default')
+    activity_signal, info = emg_activation(amplitude, sampling_rate=sampling_rate, threshold="default")
 
     # Prepare output
-    signals = pd.DataFrame({"EMG_Raw": emg_signal,
-                            "EMG_Clean": emg_cleaned,
-                            "EMG_Amplitude": amplitude})
+    signals = pd.DataFrame({"EMG_Raw": emg_signal, "EMG_Clean": emg_cleaned, "EMG_Amplitude": amplitude})
 
     signals = pd.concat([signals, activity_signal], axis=1)
 
