@@ -1,5 +1,10 @@
-"""Submodule for NeuroKit."""
+"""
+Submodule for NeuroKit.
+"""
 
 from .epochs_create import epochs_create
-from .epochs_to_df import epochs_to_df
 from .epochs_plot import epochs_plot
+from .epochs_to_df import epochs_to_df
+
+
+__all__ = ["epochs_create", "epochs_to_df", "epochs_plot"]
