@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
-import numpy as np
-
 import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
 
 from .epochs_to_df import epochs_to_df
 
@@ -38,13 +37,16 @@ def epochs_plot(epochs, legend=True, show=True):
     >>> data = nk.data("bio_eventrelated_100hz")
     >>> events = nk.events_find(data["Photosensor"], threshold_keep='below', event_conditions=["Negative", "Neutral", "Neutral", "Negative"])
     >>> epochs = nk.epochs_create(data, events, sampling_rate=200, epochs_end=1)
-    >>> nk.epochs_plot(epochs)
+    >>> fig1 = nk.epochs_plot(epochs)
+    >>> fig1 #doctest: +SKIP
     >>>
     >>> # Example with ECG Peaks
     >>> signal = nk.ecg_simulate(duration=10)
     >>> events = nk.ecg_findpeaks(signal)
     >>> epochs = nk.epochs_create(signal, events=events["ECG_R_Peaks"], epochs_start=-0.5, epochs_end=0.5)
-    >>> nk.epochs_plot(epochs)
+    >>> fig2 = nk.epochs_plot(epochs)
+    >>> fig2 #doctest: +SKIP
+
     """
     data = epochs_to_df(epochs)
 
@@ -64,10 +66,11 @@ def epochs_plot(epochs, legend=True, show=True):
     else:
         return data
 
+
 def _epochs_plot(data, ax, col, legend):
 
     if "Condition" in data.columns:
-        grouped = data.groupby('Condition')
+        grouped = data.groupby("Condition")
 
         # Colors
         color_list = ["red", "blue", "green", "yellow", "purple", "orange", "cyan", "magenta"]
@@ -77,9 +80,9 @@ def _epochs_plot(data, ax, col, legend):
 
         # Plot
         for key, group in grouped:
-            df = group.pivot_table(index='Time', columns=["Condition", 'Label'], values=col)
+            df = group.pivot_table(index="Time", columns=["Condition", "Label"], values=col)
             df.plot(ax=ax, label=col, title=col, style=colors[key], legend=legend)
 
         # TODO: Custom legend
     else:
-        data.pivot(index='Time', columns='Label', values=col).plot(ax=ax, label=col, title=col, legend=legend)
+        data.pivot(index="Time", columns="Label", values=col).plot(ax=ax, label=col, title=col, legend=legend)
