@@ -1,5 +1,10 @@
-"""Submodule for NeuroKit."""
+"""
+Submodule for NeuroKit.
+"""
 
 from .events_find import events_find
 from .events_plot import events_plot
 from .events_to_mne import events_to_mne
+
+
+__all__ = ["events_find", "events_plot", "events_to_mne"]
