@@ -2,13 +2,16 @@
 
 
 def listify(**kwargs):
-    """Transforms arguments into lists of the same length.
+    """
+    Transforms arguments into lists of the same length.
 
     Examples
     --------
     >>> import neurokit2 as nk
     >>>
-    >>> nk.listify(a=3, b=[3, 5], c=[3])
+    >>> nk.listify(a=3, b=[3, 5], c=[3]) #doctest: +ELLIPSIS
+    {'a': [3, 3], 'b': [3, 5], 'c': [3, 3]}
+
     """
     args = kwargs
     maxi = 1
@@ -32,9 +35,6 @@ def listify(**kwargs):
     return args
 
 
-
-
-
 def _multiply_list(lst, length):
     q, r = divmod(length, len(lst))
     return q * lst + lst[:r]
