@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
+from ..misc import as_vector
 from ..signal import signal_filter
-from ..misc import sanitize_input
 
 
 def ppg_clean(ppg_signal, sampling_rate=1000, method="elgendi"):
-    """Clean a photoplethysmogram (PPG) signal.
+    """
+    Clean a photoplethysmogram (PPG) signal.
 
     Prepare a raw PPG signal for systolic peak detection.
 
@@ -37,27 +38,25 @@ def ppg_clean(ppg_signal, sampling_rate=1000, method="elgendi"):
     >>> ppg = nk.ppg_simulate(heart_rate=75, duration=30)
     >>> ppg_clean = nk.ppg_clean(ppg)
     >>>
-    >>> plt.plot(ppg, label="raw PPG")
-    >>> plt.plot(ppg_clean, label="clean PPG")
-    >>> plt.legend()
+    >>> plt.plot(ppg, label="raw PPG") #doctest: +SKIP
+    >>> plt.plot(ppg_clean, label="clean PPG") #doctest: +SKIP
+    >>> plt.legend() #doctest: +SKIP
+
     """
-    ppg_signal = sanitize_input(ppg_signal,
-                                message="NeuroKit error: ppg_clean(): Please"
-                                " provide the signal in vector form, i.e., a"
-                                " one-dimensional array (e.g., a list).")
+    ppg_signal = as_vector(ppg_signal)
 
     method = method.lower()
     if method in ["elgendi"]:
         clean = _ppg_clean_elgendi(ppg_signal, sampling_rate)
     else:
-        raise ValueError("Neurokit error: Please use one of the following"
-                         " methods: 'elgendi'.")
+        raise ValueError("Neurokit error: Please use one of the following methods: 'elgendi'.")
 
     return clean
 
 
 def _ppg_clean_elgendi(ppg_signal, sampling_rate):
 
-    filtered = signal_filter(ppg_signal, sampling_rate=sampling_rate,
-                             lowcut=.5, highcut=8, order=3, method="butter_ba")
+    filtered = signal_filter(
+        ppg_signal, sampling_rate=sampling_rate, lowcut=0.5, highcut=8, order=3, method="butter_ba"
+    )
     return filtered
