@@ -2,13 +2,13 @@
 import numpy as np
 import scipy.signal
 
-from ..signal import signal_detrend
-from ..signal import signal_filter
-from ..misc import sanitize_input
+from ..misc import as_vector
+from ..signal import signal_detrend, signal_filter
 
 
 def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
-    """Preprocess a respiration (RSP) signal.
+    """
+    Preprocess a respiration (RSP) signal.
 
     Clean a respiration signal using different sets of parameters, such as
     'khodadad2018' (linear detrending followed by a fifth order 2Hz low-pass
@@ -34,7 +34,7 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
 
     See Also
     --------
-    rsp_findpeaks, rsp_rate, rsp_amplitude, rsp_process, rsp_plot
+    rsp_findpeaks, signal_rate, rsp_amplitude, rsp_process, rsp_plot
 
     Examples
     --------
@@ -42,21 +42,16 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
     >>> import neurokit2 as nk
     >>>
     >>> rsp = nk.rsp_simulate(duration=30, sampling_rate=50, noise=0.01)
-    >>> signals = pd.DataFrame({
-            "RSP_Raw": rsp,
-            "RSP_Khodadad2018": nk.rsp_clean(rsp, sampling_rate=50, method="khodadad2018"),
-            "RSP_BioSPPy": nk.rsp_clean(rsp, sampling_rate=50, method="biosppy")})
-    >>> signals.plot()
+    >>> signals = pd.DataFrame({ "RSP_Raw": rsp, "RSP_Khodadad2018": nk.rsp_clean(rsp, sampling_rate=50, method="khodadad2018"), "RSP_BioSPPy": nk.rsp_clean(rsp, sampling_rate=50, method="biosppy")})
+    >>> fig = signals.plot()
+    >>> fig #doctest: +SKIP
 
     References
     ----------
     - `Khodadad et al. (2018) <https://iopscience.iop.org/article/10.1088/1361-6579/aad7e6/meta>`_
 
     """
-    rsp_signal = sanitize_input(rsp_signal,
-                                message="NeuroKit error: rsp_clean(): we "
-                                "expect the user to provide a vector, i.e., "
-                                "a one-dimensional array (such as a list of values).")
+    rsp_signal = as_vector(rsp_signal)
 
     method = method.lower()  # remove capitalised letters
     if method in ["khodadad", "khodadad2018"]:
@@ -64,8 +59,7 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
     elif method == "biosppy":
         clean = _rsp_clean_biosppy(rsp_signal, sampling_rate)
     else:
-        raise ValueError("NeuroKit error: rsp_clean(): 'method' should be "
-                         "one of 'khodadad2018' or 'biosppy'.")
+        raise ValueError("NeuroKit error: rsp_clean(): 'method' should be one of 'khodadad2018' or 'biosppy'.")
 
     return clean
 
@@ -74,10 +68,12 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
 # Khodadad et al. (2018)
 # =============================================================================
 def _rsp_clean_khodadad2018(rsp_signal, sampling_rate=1000):
-    """The algorithm is based on (but not an exact
-    implementation of) the "Zero-crossing algorithm with amplitude threshold"
-    by `Khodadad et al. (2018)
+    """
+    The algorithm is based on (but not an exact implementation of) the "Zero-crossing algorithm with amplitude
+    threshold" by `Khodadad et al. (2018)
+
     <https://iopscience.iop.org/article/10.1088/1361-6579/aad7e6/meta>`_.
+
     """
     # Slow baseline drifts / fluctuations must be removed from the raw
     # breathing signal (i.e., the signal must be centered around zero) in order
@@ -87,8 +83,9 @@ def _rsp_clean_khodadad2018(rsp_signal, sampling_rate=1000):
     # higher than 3 breath per minute) and high frequency noise by applying a
     # highcut at 3 Hz (preserves breathing rates slower than 180 breath per
     # minute).
-    clean = signal_filter(rsp_signal, sampling_rate=sampling_rate, lowcut=.05,
-                          highcut=3, order=2, method="butterworth_ba")
+    clean = signal_filter(
+        rsp_signal, sampling_rate=sampling_rate, lowcut=0.05, highcut=3, order=2, method="butterworth_ba"
+    )
 
     return clean
 
@@ -97,8 +94,11 @@ def _rsp_clean_khodadad2018(rsp_signal, sampling_rate=1000):
 # BioSPPy
 # =============================================================================
 def _rsp_clean_biosppy(rsp_signal, sampling_rate=1000):
-    """Uses the same defaults as `BioSPPy
+    """
+    Uses the same defaults as `BioSPPy.
+
     <https://github.com/PIA-Group/BioSPPy/blob/master/biosppy/signals/resp.py>`_.
+
     """
     # Parameters
     order = 2
@@ -106,7 +106,7 @@ def _rsp_clean_biosppy(rsp_signal, sampling_rate=1000):
     frequency = 2 * np.array(frequency) / sampling_rate  # Normalize frequency to Nyquist Frequency (Fs/2).
 
     # Filtering
-    b, a = scipy.signal.butter(N=order, Wn=frequency, btype='bandpass', analog=False)
+    b, a = scipy.signal.butter(N=order, Wn=frequency, btype="bandpass", analog=False)
     filtered = scipy.signal.filtfilt(b, a, rsp_signal)
 
     # Baseline detrending
