@@ -1,21 +1,19 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 import numpy as np
+import pandas as pd
 import sklearn.mixture
 
 
-
-
-
 def signal_binarize(signal, method="threshold", threshold="auto"):
-    """Binarize a continuous signal.
+    """
+    Binarize a continuous signal.
 
     Convert a continuous signal into zeros and ones depending on a given threshold.
 
     Parameters
     ----------
     signal : list, array or Series
-        The signal channel in the form of a vector of values.
+        The signal (i.e., a time series) in the form of a vector of values.
     method : str
         The algorithm used to discriminate between the two states. Can be one of 'mixture'
         (default) or 'threshold'. If 'mixture', will use a Gaussian Mixture Model to categorize
@@ -41,7 +39,9 @@ def signal_binarize(signal, method="threshold", threshold="auto"):
     >>>
     >>> signal = np.cos(np.linspace(start=0, stop=20, num=1000))
     >>> binary = nk.signal_binarize(signal)
-    >>> pd.DataFrame({"Raw": signal, "Binary": binary}).plot()
+    >>> fig = pd.DataFrame({"Raw": signal, "Binary": binary}).plot()
+    >>> fig #doctest: +SKIP
+
     """
 
     # Return appropriate type
@@ -49,6 +49,7 @@ def signal_binarize(signal, method="threshold", threshold="auto"):
         binary = _signal_binarize(np.array(signal), method=method, threshold=threshold)
         signal = list(binary)
     elif isinstance(signal, pd.Series):
+        signal = signal.copy()  # Avoid annoying pandas warning
         binary = _signal_binarize(signal.values, method=method, threshold=threshold)
         signal[:] = binary
     else:
@@ -57,7 +58,6 @@ def signal_binarize(signal, method="threshold", threshold="auto"):
     return signal
 
 
-
 def _signal_binarize(signal, method="threshold", threshold="auto"):
     method = method.lower()  # remove capitalised letters
     if method == "threshold":
@@ -65,16 +65,15 @@ def _signal_binarize(signal, method="threshold", threshold="auto"):
     elif method == "mixture":
         binary = _signal_binarize_mixture(signal, threshold=threshold)
     else:
-        raise ValueError("NeuroKit error: signal_binarize(): 'method' should be "
-                         "one of 'threshold' or 'mixture'.")
+        raise ValueError("NeuroKit error: signal_binarize(): 'method' should be one of 'threshold' or 'mixture'.")
     return binary
 
 
-
 # =============================================================================
 # Methods
 # =============================================================================
 
+
 def _signal_binarize_threshold(signal, threshold="auto"):
     if threshold == "auto":
         threshold = np.mean([np.max(signal), np.min(signal)])
@@ -84,7 +83,6 @@ def _signal_binarize_threshold(signal, threshold="auto"):
     return binary
 
 
-
 def _signal_binarize_mixture(signal, threshold="auto"):
     if threshold == "auto":
         threshold = 0.5
