@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
+import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import matplotlib.pyplot as plt
 
 from ..events import events_plot
 from ..stats import standardize as nk_standardize
 
 
-def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False):
-    """Plot signal with events as vertical lines.
+def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False, **kwargs):
+    """
+    Plot signal with events as vertical lines.
 
     Parameters
     ----------
@@ -30,13 +31,12 @@ def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False):
     >>> import neurokit2 as nk
     >>>
     >>> signal = nk.signal_simulate(duration=10, sampling_rate=1000)
-    >>> nk.signal_plot(signal, sampling_rate=1000)
+    >>> nk.signal_plot(signal, sampling_rate=1000, color="red")
     >>>
-    >>> data = pd.DataFrame({"Signal2": np.cos(np.linspace(start=0, stop=20, num=1000)),
-                             "Signal3": np.sin(np.linspace(start=0, stop=20, num=1000)),
-                             "Signal4": nk.signal_binarize(np.cos(np.linspace(start=0, stop=40, num=1000)))})
+    >>> data = pd.DataFrame({"Signal2": np.cos(np.linspace(start=0, stop=20, num=1000)), "Signal3": np.sin(np.linspace(start=0, stop=20, num=1000)), "Signal4": nk.signal_binarize(np.cos(np.linspace(start=0, stop=40, num=1000)))})
     >>> nk.signal_plot(data, subplots=True)
     >>> nk.signal_plot([signal, data], standardize=True)
+
     """
     # Sanitize format
     if isinstance(signal, list):
@@ -46,7 +46,6 @@ def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False):
         except TypeError:
             signal = np.array(signal)
 
-
     if isinstance(signal, pd.DataFrame) is False:
 
         # If list is passed
@@ -76,16 +75,15 @@ def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False):
 
     # Adjust for sampling rate
     if sampling_rate is not None:
-        x_axis = np.linspace(0, signal.shape[0] / sampling_rate,
-                             signal.shape[0])
-        x_axis = pd.DataFrame(x_axis, columns=['Time (s)'])
+        x_axis = np.linspace(0, signal.shape[0] / sampling_rate, signal.shape[0])
+        x_axis = pd.DataFrame(x_axis, columns=["Time (s)"])
         signal = pd.concat([signal, x_axis], axis=1)
-        signal = signal.set_index('Time (s)')
+        signal = signal.set_index("Time (s)")
     elif sampling_rate is None:
         x_axis = np.arange(0, signal.shape[0])
-        x_axis = pd.DataFrame(x_axis, columns=['Samples'])
+        x_axis = pd.DataFrame(x_axis, columns=["Samples"])
         signal = pd.concat([signal, x_axis], axis=1)
-        signal = signal.set_index('Samples')
+        signal = signal.set_index("Samples")
 
     # Plot accordingly
     if len(events_columns) > 0:
@@ -95,14 +93,14 @@ def signal_plot(signal, sampling_rate=None, subplots=False, standardize=False):
             events.append(np.where(vector == np.max(vector.unique()))[0])
         plot = events_plot(events, signal=signal[continuous_columns])
         if sampling_rate is not None:
-            plot.gca().set_xlabel('Time (seconds)')
+            plot.gca().set_xlabel("Time (seconds)")
         elif sampling_rate is None:
-            plot.gca().set_xlabel('Samples')
+            plot.gca().set_xlabel("Samples")
     else:
         if standardize is True:
-            plot = nk_standardize(signal[continuous_columns]).plot(subplots=subplots, sharex=True)
+            plot = nk_standardize(signal[continuous_columns]).plot(subplots=subplots, sharex=True, **kwargs)
         else:
-            plot = signal[continuous_columns].plot(subplots=subplots, sharex=True)
+            plot = signal[continuous_columns].plot(subplots=subplots, sharex=True, **kwargs)
 
     # Tidy legend locations
     [plot.legend(loc=1) for plot in plt.gcf().axes]
