@@ -4,13 +4,16 @@ import pandas as pd
 import scipy.signal
 
 
-def signal_psd(signal, sampling_rate=1000, method="multitapers", show=True, min_frequency=0, max_frequency=np.inf, window=None):
-    """Compute the Power Spectral Density (PSD).
+def signal_psd(
+    signal, sampling_rate=1000, method="welch", show=True, min_frequency=0, max_frequency=np.inf, window=None
+):
+    """
+    Compute the Power Spectral Density (PSD).
 
     Parameters
     ----------
     signal : list, array or Series
-        The signal channel in the form of a vector of values.
+        The signal (i.e., a time series) in the form of a vector of values.
     sampling_rate : int
         The sampling frequency of the signal (in Hz, i.e., samples/second).
     show : bool
@@ -40,13 +43,18 @@ def signal_psd(signal, sampling_rate=1000, method="multitapers", show=True, min_
     >>>
     >>> signal = nk.signal_simulate(frequency=5) + 0.5*nk.signal_simulate(frequency=20)
     >>>
-    >>> nk.signal_psd(signal, method="multitapers")
-    >>> nk.signal_psd(signal, method="welch")
+    >>> fig1 = nk.signal_psd(signal, method="multitapers")
+    >>> fig1 #doctest: +SKIP
+    >>> fig2 = nk.signal_psd(signal, method="welch", min_frequency=1)
+    >>> fig2 #doctest: +SKIP
     >>>
     >>> data = nk.signal_psd(signal, method="multitapers", max_frequency=30, show=False)
-    >>> data.plot(x="Frequency", y="Power")
-    >>> data = nk.signal_psd(signal, method="welch", max_frequency=30, show=False)
-    >>> data.plot(x="Frequency", y="Power")
+    >>> fig3 = data.plot(x="Frequency", y="Power")
+    >>> fig3 #doctest: +SKIP
+    >>> data = nk.signal_psd(signal, method="welch", max_frequency=30, show=False, min_frequency=1)
+    >>> fig4 = data.plot(x="Frequency", y="Power")
+    >>> fig4 #doctest: +SKIP
+
     """
     # Constant Detrend
     signal = signal - np.mean(signal)
@@ -55,22 +63,26 @@ def signal_psd(signal, sampling_rate=1000, method="multitapers", show=True, min_
     if method.lower() in ["multitapers", "mne"]:
         try:
             import mne
-            power, frequency = mne.time_frequency.psd_array_multitaper(signal,
-                                                                       sfreq=sampling_rate,
-                                                                       fmin=min_frequency,
-                                                                       fmax=max_frequency,
-                                                                       adaptive=True,
-                                                                       normalization='full',
-                                                                       verbose=False)
+
+            power, frequency = mne.time_frequency.psd_array_multitaper(
+                signal,
+                sfreq=sampling_rate,
+                fmin=min_frequency,
+                fmax=max_frequency,
+                adaptive=True,
+                normalization="full",
+                verbose=False,
+            )
         except ImportError:
-            raise ImportError("NeuroKit warning: signal_psd(): the 'mne'",
-                              "module is required for the 'mne' method to run.",
-                              "Please install it first (`pip install mne`).")
+            raise ImportError(
+                "NeuroKit warning: signal_psd(): the 'mne'",
+                "module is required for the 'mne' method to run.",
+                "Please install it first (`pip install mne`).",
+            )
 
     # BURG
     elif method.lower() in ["burg", "pburg", "spectrum"]:
-        raise ValueError("NeuroKit warning: signal_psd(): the 'BURG'",
-                         "method has not been yet implemented.")
+        raise ValueError("NeuroKit warning: signal_psd(): the 'BURG' method has not been yet implemented.")
 
     # Welch (Scipy)
     else:
@@ -85,26 +97,29 @@ def signal_psd(signal, sampling_rate=1000, method="multitapers", show=True, min_
 
         # in case duration of recording is not sufficient
         if nperseg > len(signal) / 2:
-            print("Neurokit warning: signal_psd(): The duration of recording is too short to support a sufficiently long window for high frequency resolution. Consider using a longer recording or increasing the `min_frequency`")
+            print(
+                "Neurokit warning: signal_psd(): The duration of recording is too short to support a sufficiently long window for high frequency resolution. Consider using a longer recording or increasing the `min_frequency`"
+            )
             nperseg = int(len(signal / 2))
 
-        frequency, power = scipy.signal.welch(signal,
-                                              fs=sampling_rate,
-                                              scaling='density',
-                                              detrend=False,
-                                              nfft=int(nperseg*2),
-                                              average='mean',
-                                              nperseg=nperseg)
+        frequency, power = scipy.signal.welch(
+            signal,
+            fs=sampling_rate,
+            scaling="density",
+            detrend=False,
+            nfft=int(nperseg * 2),
+            average="mean",
+            nperseg=nperseg,
+        )
 
     # Store results
-    data = pd.DataFrame({"Frequency": frequency,
-                         "Power": power})
+    data = pd.DataFrame({"Frequency": frequency, "Power": power})
 
     # Filter
     data = data.loc[np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)]
 
     if show is True:
-        ax = data.plot(x="Frequency", y="Power", logy=True, title='Power Spectral Density (PSD)')
+        ax = data.plot(x="Frequency", y="Power", logy=True, title="Power Spectral Density (PSD)")
         ax.set(xlabel="Frequency (Hz)", ylabel="Spectrum")
         return ax
     else:
