@@ -4,9 +4,9 @@ import numpy as np
 from ..misc import listify
 
 
-def signal_simulate(duration=10, sampling_rate=1000, frequency=1,
-                    amplitude=0.5, noise=0, silent=False):
-    """Simulate a continuous signal.
+def signal_simulate(duration=10, sampling_rate=1000, frequency=1, amplitude=0.5, noise=0, silent=False):
+    """
+    Simulate a continuous signal.
 
     Parameters
     ----------
@@ -36,9 +36,8 @@ def signal_simulate(duration=10, sampling_rate=1000, frequency=1,
     >>> import pandas as pd
     >>> import neurokit2 as nk
     >>>
-    >>> pd.DataFrame({"1Hz": nk.signal_simulate(duration=5, frequency=1),
-                      "2Hz": nk.signal_simulate(duration=5, frequency=2),
-                      "Multi": nk.signal_simulate(duration=5, frequency=[0.5, 3], amplitude=[0.5, 0.2])}).plot()
+    >>> fig = pd.DataFrame({"1Hz": nk.signal_simulate(duration=5, frequency=1), "2Hz": nk.signal_simulate(duration=5, frequency=2), "Multi": nk.signal_simulate(duration=5, frequency=[0.5, 3], amplitude=[0.5, 0.2])}).plot()
+    >>> fig #doctest: +SKIP
 
     """
     n_samples = int(np.rint(duration * sampling_rate))
@@ -54,30 +53,32 @@ def signal_simulate(duration=10, sampling_rate=1000, frequency=1,
         amp = params["amplitude"][i]
         # Apply a very conservative Nyquist criterion in order to ensure
         # sufficiently sampled signals.
-        nyquist = sampling_rate * .1
+        nyquist = sampling_rate * 0.1
         if freq > nyquist:
             if not silent:
-                print(f"NeuroKit warning: Skipping requested frequency"
-                      f" of {freq} Hz since it cannot be resolved at the"
-                      f" sampling rate of {sampling_rate} Hz. Please increase"
-                      f" sampling rate to {freq * 10} Hz or choose frequencies"
-                      f" smaller than or equal to {nyquist} Hz.")
+                print(
+                    f"NeuroKit warning: Skipping requested frequency"
+                    f" of {freq} Hz since it cannot be resolved at the"
+                    f" sampling rate of {sampling_rate} Hz. Please increase"
+                    f" sampling rate to {freq * 10} Hz or choose frequencies"
+                    f" smaller than or equal to {nyquist} Hz."
+                )
             continue
         # Also make sure that at leat one period of the frequency can be
         # captured over the duration of the signal.
         if (1 / freq) > duration:
             if not silent:
-                print(f"NeuroKit warning: Skipping requested frequency"
-                      f" of {freq} Hz since it's period of {1 / freq} seconds"
-                      f" exceeds the signal duration of {duration} seconds."
-                      f" Please choose frequencies larger than"
-                      f" {1 / duration} Hz or increase the duration of the"
-                      f" signal above {1 / freq} seconds.")
+                print(
+                    f"NeuroKit warning: Skipping requested frequency"
+                    f" of {freq} Hz since it's period of {1 / freq} seconds"
+                    f" exceeds the signal duration of {duration} seconds."
+                    f" Please choose frequencies larger than"
+                    f" {1 / duration} Hz or increase the duration of the"
+                    f" signal above {1 / freq} seconds."
+                )
             continue
 
-        signal += _signal_simulate_sinusoidal(x=seconds,
-                                              frequency=freq,
-                                              amplitude=amp)
+        signal += _signal_simulate_sinusoidal(x=seconds, frequency=freq, amplitude=amp)
         # Add random noise
         if noise > 0:
             signal += np.random.laplace(0, noise, len(signal))
