@@ -5,7 +5,8 @@ import sklearn.mixture
 
 
 def fit_mixture(X=None, n_clusters=2):
-    """Gaussian Mixture Model
+    """
+    Gaussian Mixture Model.
 
     Performs a polynomial regression of given order.
 
@@ -35,7 +36,9 @@ def fit_mixture(X=None, n_clusters=2):
     >>>
     >>> x = nk.signal_simulate()
     >>> probs = nk.fit_mixture(x, n_clusters=2)
-    >>> nk.signal_plot([x, probs["Cluster_0"], probs["Cluster_1"]], standardize=True)
+    >>> fig = nk.signal_plot([x, probs["Cluster_0"], probs["Cluster_1"]], standardize=True)
+    >>> fig #doctest: +SKIP
+
     """
     if X.ndim == 1:
         X = X.reshape(-1, 1)
@@ -46,6 +49,6 @@ def fit_mixture(X=None, n_clusters=2):
 
     # Get predicted probabilities
     predicted = clf.predict_proba(X)
-    probabilities = pd.DataFrame(predicted).add_prefix('Cluster_')
+    probabilities = pd.DataFrame(predicted).add_prefix("Cluster_")
 
     return probabilities
