@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 import numpy as np
-
-
-
+import pandas as pd
 
 
 def rescale(data, to=[0, 1]):
-    """Rescale data.
+    """
+    Rescale data.
 
     Rescale a numeric variable to a new range.
 
@@ -28,7 +26,9 @@ def rescale(data, to=[0, 1]):
     ----------
     >>> import neurokit2 as nk
     >>>
-    >>> nk.rescale(data=[3, 1, 2, 4, 6], to=[0, 1])
+    >>> nk.rescale(data=[3, 1, 2, 4, 6], to=[0, 1]) #doctest: +ELLIPSIS
+    [0.4, 0.0, 0.2, 0.6000000000000001, 1.0]
+
     """
 
     # Return appropriate type
@@ -40,11 +40,8 @@ def rescale(data, to=[0, 1]):
     return data
 
 
-
-
-
-
-
+# =============================================================================
+# Internals
+# =============================================================================
 def _rescale(data, to=[0, 1]):
-    y = (to[1] - to[0]) / (np.nanmax(data) - np.nanmin(data)) * (data - np.nanmin(data)) + to[0]
-    return y
+    return (to[1] - to[0]) / (np.nanmax(data) - np.nanmin(data)) * (data - np.nanmin(data)) + to[0]
