@@ -1,16 +1,13 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 import numpy as np
+import pandas as pd
 
 from .mad import mad
 
 
-
-
-
-
 def standardize(data, robust=False):
-    """Standardization of data
+    """
+    Standardization of data.
 
     Performs a standardization of data (Z-scoring), i.e., centering and scaling,
     so that the data is expressed in terms of standard deviation
@@ -36,10 +33,11 @@ def standardize(data, robust=False):
     ----------
     >>> import neurokit2 as nk
     >>>
-    >>> nk.standardize([3, 1, 2, 4, 6, np.nan])
-    >>> nk.standardize([3, 1, 2, 4, 6, np.nan], robust=True)
-    >>> nk.standardize(pd.DataFrame({"A": [3, 1, 2, 4, 6, np.nan],
-                                     "B": [3, 1, 2, 4, 6, 5]}))
+    >>> x = nk.standardize([3, 1, 2, 4, 6, np.nan])
+    >>> y = nk.standardize([3, 1, 2, 4, 6, np.nan], robust=True)
+    >>> z = nk.standardize(pd.DataFrame({"A": [3, 1, 2, 4, 6, np.nan], "B": [3, 1, 2, 4, 6, 5]}))
+    >>> z #doctest: +SKIP
+
     """
     # Return appropriate type
     if isinstance(data, list):
@@ -50,15 +48,12 @@ def standardize(data, robust=False):
     return data
 
 
-
-
-
 def _standardize(data, robust=False):
 
     # Compute standardized
     if robust is False:
-        z = (data - np.nanmean(data, axis=0))/np.nanstd(data, axis=0, ddof=1)
+        z = (data - np.nanmean(data, axis=0)) / np.nanstd(data, axis=0, ddof=1)
     else:
-        z = (data - np.nanmedian(data, axis=0))/mad(data)
+        z = (data - np.nanmedian(data, axis=0)) / mad(data)
 
     return z
